#include <sys/types.h>
#include <sys/time.h>

#include <stdio.h>
#include <errno.h>
#include <string.h>
#include <unistd.h>
#include <stdlib.h>

#include <libraw1394/raw1394.h>
#include <libraw1394/csr.h>
#include <libavc1394/avc1394.h>

#include "avc.h"
#include "plug.h"
#include "support.h"

const char not_compatible[] = "\n"
    "This libraw1394 does not work with your version of Linux. You need a different\n"
    "version that matches your kernel (see kernel help text for the raw1394 option to\n"
    "find out which is the correct version).\n";

const char not_loaded[] = "\n"
    "This probably means that you don't have raw1394 support in the kernel or that\n"
    "you haven't loaded the raw1394 module.\n";

/* global flag to signal termination */
int g_done = 0;

int main(int argc, char **argv)
{
    raw1394handle_t handle;

    init_debug();

    handle = raw1394_new_handle();

    if (!handle) {
	if (!errno) {
	    printf(not_compatible);
	} else {
	    perror("couldn't get handle");
	    printf(not_loaded);
	}
	exit(EXIT_FAILURE);
    }

    if (raw1394_set_port(handle, 0) < 0) {
	perror("couldn't set port");
	exit(EXIT_FAILURE);
    }

    // prepare plugs
    plug_register(handle);
    // prepare target
    avc1394_init_target(handle, avc_command_handler);

    printf("Starting AV/C target; press Ctrl+C to quit...\n");
    while (g_done <= 0) {
	g_done = raw1394_loop_iterate(handle);
    }

    // close target
    avc1394_close_target(handle);
    // close plugs
    plug_unregister(handle);

    exit(EXIT_SUCCESS);
}
