#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <stdarg.h>

static char *avc_commands[256];

void eprintf(char *format, ...)
{
    va_list vl;
    char debugbuf[2048];

    va_start(vl, format);
    vsnprintf(debugbuf, 2048, format, vl);
    va_end(vl);

    fprintf(stderr, debugbuf);
}

void init_debug(void)
{

    memset(avc_commands, 0, sizeof(avc_commands));

    /* unit commands
    #define AVC1394_CMD_CONNECTIONS 0x22
    #define AVC1394_CMD_DIGITAL_INPUT 0x11
    #define AVC1394_CMD_DIGITAL_OUTPUT 0x10
    #define AVC1394_CMD_DISCONNECT 0x25
    #define AVC1394_CMD_DISCONNECT_AV 0x21
    */
    avc_commands[0x12] = "AVC1394_CMD_CHANNEL_USAGE";
    avc_commands[0x18] = "AVC1394_CMD_OUTPUT_PLUG_SIGNAL_FORMAT";
    avc_commands[0x19] = "AVC1394_CMD_INPUT_PLUG_SIGNAL_FORMAT";

    avc_commands[0x20] = "AVC1394_CMD_CONNECT_AV";
    avc_commands[0x24] = "AVC1394_CMD_CONNECT";
    avc_commands[0x30] = "AVC1394_CMD_UNIT_INFO";
    avc_commands[0x31] = "AVC1394_CMD_SUBUNIT_INFO";

    /* common unit + subunit commands
    #define AVC1394_CMD_OPEN_DESCRIPTOR 0x08
    #define AVC1394_CMD_READ_DESCRIPTOR 0x09
    #define AVC1394_CMD_WRITE_DESCRIPTOR 0x0A
    #define AVC1394_CMD_SEARCH_DESCRIPTOR 0x0B
    #define AVC1394_CMD_OBJECT_NUMBER_SELECT 0x0D
    #define AVC1394_CMD_RESERVE 0x01
    #define AVC1394_CMD_PLUG_INFO 0x02
    */
    avc_commands[0x00] = "AVC1394_CMD_VENDOR_DEPENDENT";
    avc_commands[0xB2] = "AVC1394_CMD_POWER";

    /* vcr subunit commands
    #define AVC1394_VCR_CMD_ANALOG_AUDIO_OUTPUT_MODE 0x70
    #define AVC1394_VCR_CMD_AREA_MODE 0x72
    #define AVC1394_VCR_CMD_ABSOLUTE_TRACK_NUMBER 0x52
    #define AVC1394_VCR_CMD_AUDIO_MODE 0x71
    #define AVC1394_VCR_CMD_BACKWARD 0x56
    #define AVC1394_VCR_CMD_BINARY_GROUP 0x5A
    #define AVC1394_VCR_CMD_EDIT_MODE 0x40
    #define AVC1394_VCR_CMD_FORWARD 0x55
    #define AVC1394_VCR_CMD_LOAD_MEDIUM 0xC1
    #define AVC1394_VCR_CMD_MARKER 0xCA
    #define AVC1394_VCR_CMD_OPEN_MIC 0x60
    #define AVC1394_VCR_CMD_PRESET 0x45
    #define AVC1394_VCR_CMD_READ_MIC 0x61
    #define AVC1394_VCR_CMD_RECORDING_DATE 0x53
    #define AVC1394_VCR_CMD_RECORDING_TIME 0x54
    #define AVC1394_VCR_CMD_SEARCH_MODE 0x50
    #define AVC1394_VCR_CMD_SMPTE_EBU_RECORDING_TIME 0x5C
    #define AVC1394_VCR_CMD_SMPTE_EBU_TIME_CODE 0x59
    #define AVC1394_VCR_CMD_TIME_CODE 0x51
    #define AVC1394_VCR_CMD_WRITE_MIC 0x62
    */
    avc_commands[0x57] = "AVC1394_VCR_CMD_RELATIVE_TIME_COUNTER";
    avc_commands[0x78] = "AVC1394_VCR_CMD_OUTPUT_SIGNAL_MODE";
    avc_commands[0x79] = "AVC1394_VCR_CMD_INPUT_SIGNAL_MODE";
    avc_commands[0xC2] = "AVC1394_VCR_CMD_RECORD";
    avc_commands[0xC3] = "AVC1394_VCR_CMD_PLAY";
    avc_commands[0xC4] = "AVC1394_VCR_CMD_WIND";
    avc_commands[0xD0] = "AVC1394_VCR_CMD_TRANSPORT_STATE";
    avc_commands[0xD2] = "AVC1394_VCR_CMD_TAPE_RECORDING_FORMAT";
    avc_commands[0xD3] = "AVC1394_VCR_CMD_TAPE_PLAYBACK_FORMAT";
    avc_commands[0xDA] = "AVC1394_VCR_CMD_MEDIUM_INFO";
    avc_commands[0xDB] = "AVC1394_VCR_CMD_RECORDING_SPEED";


}

char *avc_command_name(int cmd)
{
    static char buf[256];

    if (avc_commands[cmd] != 0)
	return avc_commands[cmd];
    else {
	sprintf(buf, "UNKNOWN (0x%02x)", cmd);
	return buf;
    }
}

